@@ -269,10 +269,8 @@ public class Gridder  {
 	    drawLine(lon-1.e-10, lon-1.e-10, latLimits[0],latLimits[1]);
 	}
 	for (double lat=latValues[0]; lat <= latLimits[1]; lat += latValues[1]) {
-            System.err.println("Lat is:"+lat);
             if (Math.abs(Math.abs(lat)-90) < 1.e-5) {
                 // Don't draw lines at 90 degrees latitude.
-                System.err.println("Skipping lat 90");
                 continue;
             }
 	    fm.setSeparators(new String[]{"\u00B0", "'", "\""});
